@@ -22,7 +22,7 @@ type Manager struct {
 const (
 	dbusServiceName = "org.deepin.dde.Search1"
 	dbusPath        = "/org/deepin/dde/Search1"
-	dbusInterface   = "org.deepin.dde.Search1"
+	dbusInterface   = dbusServiceName
 )
 
 var (
