@@ -8,7 +8,6 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
-	configManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
 	"math"
 	"os"
 	"os/exec"
@@ -19,11 +18,15 @@ import (
 	"sync"
 	"time"
 
+	configManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
+
 	"github.com/davecgh/go-spew/spew"
 	"github.com/godbus/dbus/v5"
 	"github.com/linuxdeepin/dde-api/dxinput"
 	dxutil "github.com/linuxdeepin/dde-api/dxinput/utils"
+	"github.com/linuxdeepin/dde-daemon/common/scale"
 	"github.com/linuxdeepin/dde-daemon/display1/brightness"
+	xs "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.xsettings1"
 	sysdisplay "github.com/linuxdeepin/go-dbus-factory/system/org.deepin.dde.display1"
 	dgesture "github.com/linuxdeepin/go-dbus-factory/system/org.deepin.dde.gesture1"
 	inputdevices "github.com/linuxdeepin/go-dbus-factory/system/org.deepin.dde.inputdevices1"
@@ -228,6 +231,8 @@ type Manager struct {
 	ColorTemperatureManual    int32
 	CustomColorTempTimePeriod string
 
+	xsManager xs.XSettings
+
 	isVM bool
 }
 
@@ -253,6 +258,9 @@ func newManager(service *dbusutil.Service) *Manager {
 		},
 		isVM: isVM,
 	}
+	if !_greeterMode {
+		m.xsManager = xs.NewXSettings(m.service.Conn())
+	}
 	m.redshiftRunner.cb = func(value int) {
 		m.setColorTempOneShot()
 	}
@@ -2092,30 +2100,30 @@ func (m *Manager) applySysMonitorConfigs(mode byte, monitorsId monitorsId, monit
 		m.setPropDisplayMode(mode)
 	}
 
-	// 异步处理亮度设置
-	go func() {
-		for _, config := range configs {
-			if config.Enabled {
-				err := m.setBrightness(config.Name, config.Brightness)
-				if err != nil {
-					logger.Warningf("call setBrightness err: %v, config.Name: %s", err, config.Name)
-					monitors := m.getConnectedMonitors()
-					monitor := monitors.GetByUuid(config.UUID)
-					// 插拔过程中存在异常monitor空
-					if monitor == nil {
-						logger.Warning("call GetByUuid failed: ", config.UUID)
-						continue
-					}
+	// 不能放在线程中设置亮度，因为后续在设置色温的时候亮度可能还没有设置完成，这时亮度的属性值还没有真正的改变
+	// cfg的值没有设置到monitorMap中，后面再设置色温的时候拿到的monitorMap中的亮度值就是错误的。
+	// TODO：色温和设置亮度都调用了setBrightness的接口，逻辑重复了，需要优化。
+	for _, config := range configs {
+		if config.Enabled {
+			err := m.setBrightness(config.Name, config.Brightness)
+			if err != nil {
+				logger.Warningf("call setBrightness err: %v, config.Name: %s", err, config.Name)
+				monitors := m.getConnectedMonitors()
+				monitor := monitors.GetByUuid(config.UUID)
+				// 插拔过程中存在异常monitor空
+				if monitor == nil {
+					logger.Warning("call GetByUuid failed: ", config.UUID)
+					continue
+				}
 
-					err := m.setBrightness(monitor.Name, config.Brightness)
-					if err != nil {
-						logger.Warningf("call setBrightness err: %v, monitor.Name: %s", err, monitor.Name)
-					}
+				err := m.setBrightness(monitor.Name, config.Brightness)
+				if err != nil {
+					logger.Warningf("call setBrightness err: %v, monitor.Name: %s", err, monitor.Name)
 				}
 			}
 		}
-		m.syncPropBrightness()
-	}()
+	}
+	m.syncPropBrightness()
 
 	// NOTE: Primary 和 PrimaryRect 属性改变信号应该在 DisplayMode 属性改变之后，否则会引发前端 dcc 的 bug。
 	err = m.mm.setMonitorPrimary(primaryMonitorID)
@@ -3042,3 +3050,49 @@ func (m *Manager) detectDrmSupportGamma() bool {
 	}
 	return false
 }
+
+// 从控制中心迁移过来计算屏幕缩放范围。此函数返回屏幕最大的缩放值
+func calcMaxScaleFactor(width, height uint16) float64 {
+	scaleFactors := []float64{1.0, 1.25, 1.5, 1.75, 2.0, 2.25, 2.5, 2.75, 3.0}
+
+	maxWScale := float64(width) / 1024.0
+	maxHScale := float64(height) / 768.0
+
+	maxValue := 0.0
+	if maxWScale < maxHScale {
+		maxValue = maxWScale
+	} else {
+		maxValue = maxHScale
+	}
+
+	if maxValue > 3.0 {
+		maxValue = 3.0
+	}
+
+	maxScale := 0.0
+	for idx := 0; (float64(idx)*0.25 + 1.0) <= maxValue; idx++ {
+		maxScale = scaleFactors[idx]
+	}
+
+	return maxScale
+}
+
+func (m *Manager) tryToChangeScaleFactor(monitorWidth, monitorHeight uint16) {
+	// x 下拔掉显示器会触发更新操作，高宽均为0
+	if monitorWidth == 0 || monitorHeight == 0 {
+		return
+	}
+
+	curScale, err := m.xsManager.GetScaleFactor(0)
+	if err != nil {
+		logger.Warning("failed to get scale factor:", err)
+		return
+	}
+
+	maxScale := calcMaxScaleFactor(monitorWidth, monitorHeight)
+	if curScale > maxScale && m.xsManager != nil {
+		recommendScaleFactor := scale.GetRecommendedScaleFactor(m.xConn)
+		// 更新scale factor
+		m.xsManager.SetScaleFactor(0, recommendScaleFactor)
+	}
+}
