@@ -8,6 +8,7 @@ import (
 	"crypto/sha256"
 	"encoding/hex"
 	"encoding/json"
+
 	"github.com/linuxdeepin/go-lib/appinfo/desktopappinfo"
 	"github.com/linuxdeepin/go-lib/strv"
 
@@ -20,13 +21,13 @@ import (
 	dbus "github.com/godbus/dbus/v5"
 	"github.com/linuxdeepin/dde-daemon/keybinding1/shortcuts"
 	configManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
-	lockfront "github.com/linuxdeepin/go-dbus-factory/session/com.deepin.dde.lockfront"
-	shutdownfront "github.com/linuxdeepin/go-dbus-factory/session/com.deepin.dde.shutdownfront"
 	wm "github.com/linuxdeepin/go-dbus-factory/session/com.deepin.wm"
 	inputdevices "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.inputdevices1"
 	kwayland "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.kwayland1"
+	lockfront "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.lockfront1"
 	network "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.network1"
 	sessionmanager "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.sessionmanager1"
+	shutdownfront "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.shutdownfront1"
 	newAppmanager "github.com/linuxdeepin/go-dbus-factory/session/org.desktopspec.applicationmanager1"
 	airplanemode "github.com/linuxdeepin/go-dbus-factory/system/org.deepin.dde.airplanemode1"
 	backlight "github.com/linuxdeepin/go-dbus-factory/system/org.deepin.dde.backlighthelper1"
@@ -486,7 +487,6 @@ var kwinSysActionCmdMap = map[string]string{
 	"Deepin Picker":         "color-picker",           // ctrl+alt+v
 	"System Monitor":        "system-monitor",         // ctrl+alt+escape
 	"Screen Recorder":       "deepin-screen-recorder", // deepin-screen-recorder ctrl+alt+r
-	"Desktop AI Assistant":  "ai-assistant",           // ai-assistant [<Super>Q]q
 	"Text to Speech":        "text-to-speech",
 	"Speech to Text":        "speech-to-text",
 	"Clipboard":             "clipboard",
