@@ -20,10 +20,10 @@ import (
 	"github.com/linuxdeepin/dde-daemon/session/common"
 	configManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
 	calendar "github.com/linuxdeepin/go-dbus-factory/session/com.deepin.dataserver.Calendar"
-	shutdownfront "github.com/linuxdeepin/go-dbus-factory/session/com.deepin.dde.shutdownfront"
 	wm "github.com/linuxdeepin/go-dbus-factory/session/com.deepin.wm"
 	display "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.display1"
 	sessionmanager "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.sessionmanager1"
+	shutdownfront "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.shutdownfront1"
 	sessiontimedate "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.timedate1"
 	ofdbus "github.com/linuxdeepin/go-dbus-factory/session/org.freedesktop.dbus"
 	notifications "github.com/linuxdeepin/go-dbus-factory/session/org.freedesktop.notifications"
