@@ -53,20 +53,13 @@ func (m *Manager) initOnBatteryChangedHandler() {
 		logger.Debug("property OnBattery changed to", onBattery)
 		m.PropsMu.Lock()
 		changed := m.setPropOnBattery(onBattery)
-		state := m.lidSwitchState
 		m.PropsMu.Unlock()
 
 		if changed {
 			if onBattery {
 				playSound(soundutils.EventPowerUnplug)
-				if state == lidSwitchStateClose {
-					m.doLidClosedAction(m.BatteryLidClosedAction.Get())
-				}
 			} else {
 				playSound(soundutils.EventPowerPlug)
-				if state == lidSwitchStateClose {
-					m.doLidClosedAction(m.LinePowerLidClosedAction.Get())
-				}
 			}
 		}
 	})
@@ -78,7 +71,16 @@ func (m *Manager) initOnBatteryChangedHandler() {
 
 func (m *Manager) handleBeforeSuspend() {
 	m.setPrepareSuspend(suspendStatePrepare)
-	m.setDPMSModeOff()
+	m.setDDEBlackScreenActive(true)
+	if m.UseWayland {
+		// 如果是treeland，并且待机休眠唤醒是需要解锁，则将session 给lock
+		if m.SleepLock.Get() {
+			err := m.currentSession.Lock(0)
+			if err != nil {
+				logger.Warning("set session lock failed:", err)
+			}
+		}
+	}
 	logger.Debug("before sleep")
 }
 
@@ -88,14 +90,26 @@ func (m *Manager) handleWakeup() {
 
 	// Fix wayland sometimes no dpms event after wakeup
 	if m.UseWayland {
-		err := m.service.Conn().Object("com.deepin.daemon.KWayland",
-			"/com/deepin/daemon/KWayland/Output").Call("com.deepin.daemon.KWayland.Idle.simulateUserActivity", 0).Err
+		err := m.service.Conn().Object("org.deepin.dde.KWayland1",
+			"/org/deepin/dde/KWayland1/Output").Call("org.deepin.dde.KWayland1.Idle.simulateUserActivity", 0).Err
 
 		if err != nil {
 			logger.Warning(err)
 		}
 	}
 
+	// 系统唤醒后重新处理关机定时器
+	if m.ScheduledShutdownState {
+		m.scheduledShutdown(Init)
+	}
+
+	m.delayInActive = true
+	time.AfterFunc(time.Duration(m.delayWakeupInterval)*time.Second, func() {
+		m.delayInActive = false
+		playSound(soundutils.EventWakeup)
+		m.setDDEBlackScreenActive(false)
+	})
+
 	if v := m.submodules[submodulePSP]; v != nil {
 		if psp := v.(*powerSavePlan); psp != nil {
 			psp.HandleIdleOff()
@@ -117,8 +131,6 @@ func (m *Manager) handleWakeup() {
 			return
 		}
 	}()
-
-	playSound(soundutils.EventWakeup)
 }
 
 func (m *Manager) handleRefreshMains() {
@@ -130,6 +142,47 @@ func (m *Manager) handleRefreshMains() {
 	}
 }
 
+func (m *Manager) handleWakeupDDELowPowerCheck() {
+	power := m.helper.Power
+	hasBattery, err := power.HasBattery().Get(0)
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+
+	logger.Info(" PrepareForSleep(False) : wakeup, hasBattery : ", hasBattery)
+
+	if hasBattery {
+		// when wakeup update onBattery state
+		onBattery, err := power.OnBattery().Get(0)
+		if err != nil {
+			logger.Warning(err)
+			return
+		}
+		if onBattery != m.OnBattery {
+			m.setPropOnBattery(onBattery)
+		}
+
+		// 使用电池
+		if onBattery {
+			percentage, err := power.BatteryPercentage().Get(0)
+			if err != nil {
+				logger.Warning(err)
+				return
+			}
+			m.setPropBatteryPercentage(percentage)
+
+			logger.Info(" PrepareForSleep(False) : wakeup,  Battery percentage : ", percentage, m.BatteryPercentage[batteryDisplay], m.warnLevelConfig.ActionPercentage.Get())
+
+			if percentage <= float64(m.warnLevelConfig.ActionPercentage.Get()) {
+				return
+			}
+		}
+
+		doCloseDDELowPower()
+	}
+}
+
 func (m *Manager) handleBatteryDisplayUpdate() {
 	logger.Debug("handleBatteryDisplayUpdate")
 	power := m.helper.Power
@@ -205,6 +258,9 @@ func (m *Manager) handleWarnLevelChanged(level WarnLevel) {
 
 	switch level {
 	case WarnLevelAction:
+		if m.ScheduledShutdownState {
+			m.scheduledShutdown(Init)
+		}
 		playSound(soundutils.EventBatteryLow)
 		m.sendNotify(iconBatteryLow, "",
 			Tr("Battery critically low"))
@@ -220,7 +276,12 @@ func (m *Manager) handleWarnLevelChanged(level WarnLevel) {
 			} else if count == 5 {
 				// after 5 seconds, force suspend
 				m.disableWarnLevelCountTicker()
-				m.doSuspend()
+
+				if m.LowPowerAction.Get() == lowPowerActionSuspend {
+					m.doSuspend()
+				} else {
+					m.doHibernate()
+				}
 			}
 		})
 
@@ -247,6 +308,9 @@ func (m *Manager) handleWarnLevelChanged(level WarnLevel) {
 	case WarnLevelNone:
 		logger.Debug("Power sufficient")
 		doCloseDDELowPower()
+		if m.ScheduledShutdownState {
+			m.scheduledShutdown(Init)
+		}
 		// 由 低电量 到 电量充足，必然需要有线电源插入
 	}
 }
